use crate::client::{MediaResult as Result, Navidrome, QualifyPath};
use crate::models::generic::Playlist;
use crate::models::navidrome::{NavidromePlaylist, NavidromeTrack};
use async_trait::async_trait;

#[async_trait]
pub trait Playlists {
    async fn playlists(&self) -> Result<Vec<Playlist>>;
    async fn playlist(&self, id: String) -> Result<Playlist>;
    async fn tracks(&self, id: String) -> Result<Vec<NavidromeTrack>>;
    async fn create_playlist(&self) -> Result<Playlist>;
    async fn delete_playlist(&self) -> Result<()>;
    async fn update_playlists(&self) -> Result<()>;
}

#[async_trait]
impl Playlists for Navidrome {
    async fn playlists(&self) -> Result<Vec<Playlist>> {
        self.http
            .get(self.path("api/playlist"))
            .header("X-Nd-Authorization", format!("Bearer {}", self.token))
            .send()
            .await?
            .json::<Vec<NavidromePlaylist>>()
            .await
            .map(|pv| pv.iter().map(|p| p.into()).collect())
    }

    async fn playlist(&self, id: String) -> Result<Playlist> {
        self.http
            .get(self.path(format!("api/playlist/{}", id)))
            .header("X-Nd-Authorization", format!("Bearer {}", self.token))
            .send()
            .await?
            .json::<NavidromePlaylist>()
            .await
            .map(|pv| (&pv).into())
    }

    async fn tracks(&self, id: String) -> Result<Vec<NavidromeTrack>> {
        self.http
            .get(self.path(format!("api/playlist/{}/tracks", id)))
            .header("X-Nd-Authorization", format!("Bearer {}", self.token))
            .send()
            .await?
            .json::<Vec<NavidromeTrack>>()
            .await
    }

    async fn create_playlist(&self) -> Result<Playlist> {
        todo!()
    }

    async fn delete_playlist(&self) -> Result<()> {
        todo!()
    }

    async fn update_playlists(&self) -> Result<()> {
        todo!()
    }
}
