use crate::models::generic::Playlist;
use chrono::NaiveDateTime;
use serde::Deserialize;

#[derive(Deserialize)]
struct LoginResponse {
    id: String, // todo should be a uuid
    #[serde(rename = "isAdmin")]
    is_admin: bool,
    name: String,
    #[serde(rename = "subsonicSalt")]
    subsonic_salt: String,
    #[serde(rename = "subsonicToken")]
    subsonic_token: String,
    token: String,
    username: String,
}

#[derive(Deserialize)]
pub(crate) struct NavidromePlaylist {
    name: String,
    comment: String,
    #[serde(rename = "createdAt")]
    created_at: NaiveDateTime,
    path: String,
    public: bool,
    size: u64,
    duration: f64,
    #[serde(rename = "evaluatedAt")]
    evaluated_at: NaiveDateTime,
    id: String,
    #[serde(rename = "ownerId")]
    owner_id: String,
    #[serde(rename = "ownerName")]
    owner_name: String,
    #[serde(rename = "songCount")]
    song_count: u64,
    sync: bool,
    #[serde(rename = "updatedAt")]
    updated_at: NaiveDateTime,
}

impl From<&NavidromePlaylist> for Playlist {
    fn from(value: &NavidromePlaylist) -> Self {
        Playlist {
            name: value.name.clone(),
            comment: Some(value.comment.clone()),
            created_at: Some(value.created_at),
            file: Some(value.path.clone()),
        }
    }
}

#[derive(Deserialize, Clone)]
pub struct NavidromeTrack {
    title: String,
    artist: String,
    #[serde(rename = "albumArtist")]
    album_artist: String,
    album: String,
    #[serde(rename = "albumId")]
    album_id: String,
    #[serde(rename = "artistId")]
    artist_id: String,
    id: String,
    #[serde(rename = "mbzTrackId")]
    pub musicbrainz_track_id: Option<String>,
    #[serde(rename = "mbzReleaseTrackId")]
    musicbrainz_release_track_id: Option<String>,
}
