use crate::models::TrackedPlaylist;
use sqlx::postgres::PgPool;
use std::env;
use std::time::Duration;
use tokio::time::{interval, MissedTickBehavior};

pub async fn update_playlists_daemon() -> Result<(), Box<dyn std::error::Error>> {
    println!("Playlist daemon starting...");

    let database = PgPool::connect(&env::var("DATABASE_URL").unwrap())
        .await
        .unwrap();

    let mut ticker = interval(Duration::from_secs(1800));
    ticker.set_missed_tick_behavior(MissedTickBehavior::Skip);

    loop {
        let records_res = sqlx::query_as!(TrackedPlaylist, "SELECT * FROM \"tracked_playlist\"")
            .fetch_all(&database)
            .await;

        match records_res {
            Ok(records) => {
                for record in records {
                    update_playlist(record).await;
                }
            }

            Err(e) => {
                println!("Could not fetch tracked_playlists: {:?}", e);
            }
        }

        ticker.tick().await;
    }
}

async fn update_playlist(playlist: TrackedPlaylist) {}
